@@ -1,9 +1,9 @@
 from __future__ import annotations
-
 from abc import ABC
+
 from dataclasses import dataclass, field
 from enum import Enum, unique
-from typing import List, Union, final
+from typing import Any, List, final
 
 from ..api.utils import timestamp_now
 from ..const import ApiDeviceHardware, ApiDeviceType, ApiStateCommand
@@ -28,21 +28,21 @@ class DeviceType(Enum):
     IrDevice = ApiDeviceType.IR_DEVICE, "Infra Red Device"
     RollingScenario = ApiDeviceType.ROLLING_SCENARIO, "Rolling Scenario"
 
-    def __new__(cls, *args, **kwds):
+    def __new__(cls, *args: Any, **kwds: Any):  # type: ignore
         obj = object.__new__(cls)
         obj._value_ = args[0]
         return obj
 
     # ignore the first param since it's already set by __new__
-    def __init__(self, _: str, display: str = None):
+    def __init__(self, _: str, display: str = "") -> None:
         self._display = display
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.display
 
     # this makes sure that the description is read-only
     @property
-    def display(self):
+    def display(self) -> str:
         return self._display
 
 
@@ -58,21 +58,21 @@ class HardwareType(Enum):
     RegularSwitch = ApiDeviceHardware.REGULAR_SWITCH, "Regular Switch"
     Repeater = ApiDeviceHardware.REPEATER, "Repeater"
 
-    def __new__(cls, *args, **kwds):
+    def __new__(cls, *args: Any, **kwds: Any):  # type: ignore
         obj = object.__new__(cls)
         obj._value_ = args[0]
         return obj
 
     # ignore the first param since it's already set by __new__
-    def __init__(self, _: str, display: str = None):
+    def __init__(self, _: str, display: str = "") -> None:
         self._display = display
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.display
 
     # this makes sure that the description is read-only
     @property
-    def display(self):
+    def display(self) -> str:
         return self._display
 
 
@@ -89,7 +89,7 @@ class SwitchBeeBaseDevice(ABC):
         self.last_data_update = timestamp_now()
         self.unit_id = self.id // 10
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return self.id
 
 
@@ -115,7 +115,7 @@ class SwitchBeeBaseShutter(ABC):
         return self._position
 
     @position.setter
-    def position(self, value: Union[str, int]) -> None:
+    def position(self, value: str | int) -> None:
 
         if value == ApiStateCommand.OFF:
             self._position = 0
@@ -135,7 +135,7 @@ class SwitchBeeBaseDimmer(ABC):
         return self._brightness
 
     @brightness.setter
-    def brightness(self, value: Union[str, int]) -> None:
+    def brightness(self, value: str | int) -> None:
         if value == ApiStateCommand.OFF:
             self._brightness = 0
         elif value == ApiStateCommand.ON:
@@ -169,7 +169,6 @@ class SwitchBeeBaseTimer(ABC):
         return self._minutes_left
 
 
-
 @dataclass
 class SwitchBeeBaseThermostat(ABC):
 
@@ -183,6 +182,7 @@ class SwitchBeeBaseThermostat(ABC):
     min_temperature: int = 16
 
 
+@final
 @dataclass
 class SwitchBeeSwitch(SwitchBeeBaseSwitch, SwitchBeeBaseDevice):
     def __post_init__(self) -> None:
